/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2006 Juan Pablo Ugarte.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Authors:
 *   Daniel Espinosa Ortiz <esodan@gmail.com>
 */
#include <gladeui/glade.h>
#include <libgnomedb/libgnomedb.h>

#ifdef G_OS_WIN32
#define GLADEGNOMEDB_API __declspec(dllexport)
#else
#define GLADEGNOMEDB_API
#endif

/* This function does absolutely nothing
 * (and is for use in overriding post_create functions).
 */
void GLADEGNOMEDB_API
empty (GObject *container, GladeCreateReason reason)
{
}

/* Catalog init function */
void GLADEGNOMEDB_API
glade_gnome_db_init (void)
{
	gchar *argv[2] = {"libgnomedb-glade3", NULL};
	
	//Initation of the libgnomedb library
	
	gnome_db_init ("libgnomedb-glade3", "1.0", 1, argv);
}
